/*
 * Copyright (C) 2008 Andre Noll <maan@tuebingen.mpg.de>
 *
 * Licensed under the GPL v2. For licencing details see COPYING.
 */

/** \file user.h \brief User structures and exported symbols from user.c. */

/** The columns of the id table. */
enum user_table_columns {
	/** The numer of the directory. */
	UT_DIR_NUM,
	/** The number of bytes of all regular files in this dir owned by this id. */
	UT_BYTES,
	/** The number of files in this dir owned by this id. */
	UT_FILES,
	/** Number of columns in this table. */
	NUM_UT_COLUMNS
};

/** Information about one admissible user. */
struct user_info {
	/** User ID. */
	uint32_t uid;
	/** \sa enum uid_info_flags. */
	uint32_t flags;
	/** The user name.  */
	char *pw_name;
	/** The user table of this user.*/
	struct osl_table *table;
	/** The description of the user table. */
	struct osl_table_description *desc;
};

/** An opaque struct that contains info about which users are admissible. */
struct uid_range;

int create_user_table(uint32_t uid, struct user_info **ui_ptr);
int read_uid_file(void);
int write_uid_file(void);

void create_hash_table(unsigned bits);
int for_each_admissible_user(int (*func)(struct user_info *, void *),
		void *data);
int parse_uid_arg(const char *orig_arg, struct uid_range **ur);
int append_users(char **users, int num_users,
		struct uid_range **admissible_uids, int num_uid_ranges);
void close_user_tables(void);
int open_admissible_user_tables(struct uid_range *admissible_uids);
